@@ -29,12 +29,6 @@
 VALUE mProf;
 VALUE cProfile;
 
-#ifndef RUBY_VM
-/* Global variable to hold current profile - needed 
-   prior to Ruby 1.9 */
-static prof_profile_t* pCurrentProfile;
-#endif
-
 static prof_profile_t*
 prof_get_profile(VALUE self)
 {
@@ -50,35 +44,29 @@ prof_get_profile(VALUE self)
  */
 static FILE* trace_file = NULL;
 
-/* Copied from eval.c (1.8.x) / thread.c (1.9.2) */
+/* Copied from thread.c (1.9.3) */
 static const char *
 get_event_name(rb_event_flag_t event)
 {
   switch (event) {
-    case RUBY_EVENT_LINE:
-  return "line";
-    case RUBY_EVENT_CLASS:
-  return "class";
-    case RUBY_EVENT_END:
-  return "end";
-    case RUBY_EVENT_CALL:
-  return "call";
-    case RUBY_EVENT_RETURN:
-  return "return";
-    case RUBY_EVENT_C_CALL:
-  return "c-call";
-    case RUBY_EVENT_C_RETURN:
-  return "c-return";
-    case RUBY_EVENT_RAISE:
-  return "raise";
-
-#ifdef RUBY_VM
-    case RUBY_EVENT_SWITCH:
-  return "thread-interrupt";
-#endif
-
-    default:
-  return "unknown";
+  case RUBY_EVENT_LINE:
+    return "line";
+  case RUBY_EVENT_CLASS:
+    return "class";
+  case RUBY_EVENT_END:
+    return "end";
+  case RUBY_EVENT_CALL:
+    return "call";
+  case RUBY_EVENT_RETURN:
+    return "return";
+  case RUBY_EVENT_C_CALL:
+    return "c-call";
+  case RUBY_EVENT_C_RETURN:
+    return "c-return";
+  case RUBY_EVENT_RAISE:
+    return "raise";
+  default:
+    return "unknown";
   }
 }
 
@@ -97,11 +85,7 @@ create_method(rb_event_flag_t event, VALUE klass, ID mid, const char* source_fil
 
 
 static prof_method_t*
-#ifdef RUBY_VM
- get_method(rb_event_flag_t event, VALUE klass, ID mid, thread_data_t* thread_data)
-# else
- get_method(rb_event_flag_t event, NODE *node, VALUE klass, ID mid, thread_data_t* thread_data)
-#endif
+get_method(rb_event_flag_t event, VALUE klass, ID mid, thread_data_t* thread_data)
 {
     prof_method_key_t key;
     prof_method_t *method = NULL;
@@ -147,24 +131,15 @@ prof_pop_threads(prof_profile_t* profile)
 }
 
 /* ===========  Profiling ================= */
-#ifdef RUBY_VM
 static void
 prof_trace(prof_profile_t* profile, rb_event_flag_t event, ID mid, VALUE klass, double measurement)
-#else
-static void
-prof_trace(prof_profile_t* profile, rb_event_flag_t event, NODE *node, ID mid, VALUE klass, double measurement)
-#endif
 {
     static VALUE last_fiber_id = Qnil;
 
     VALUE thread = rb_thread_current();
     VALUE thread_id = rb_obj_id(thread);
-#if defined(HAVE_RB_FIBER_CURRENT)
     VALUE fiber = rb_fiber_current();
     VALUE fiber_id = rb_obj_id(fiber);
-#else
-    VALUE fiber_id = thread_id;
-#endif
     const char* class_name = NULL;
     const char* method_name = rb_id2name(mid);
     const char* source_file = rb_sourcefile();
@@ -189,20 +164,10 @@ prof_trace(prof_profile_t* profile, rb_event_flag_t event, NODE *node, ID mid, V
     last_fiber_id = fiber_id;
 }
 
-#ifdef RUBY_VM
 static void
 prof_event_hook(rb_event_flag_t event, VALUE data, VALUE self, ID mid, VALUE klass)
-#else
-static void
-prof_event_hook(rb_event_flag_t event, NODE *node, VALUE self, ID mid, VALUE klass)
-#endif
 {
-#ifndef RUBY_VM
-    prof_profile_t* profile = pCurrentProfile;
-#else
     prof_profile_t* profile = prof_get_profile(data);
-#endif	
-    
     VALUE thread = Qnil;
     VALUE thread_id = Qnil;
     VALUE fiber = Qnil;
@@ -211,41 +176,30 @@ prof_event_hook(rb_event_flag_t event, NODE *node, VALUE self, ID mid, VALUE kla
     prof_frame_t *frame = NULL;
     double measurement;
 
-    #ifdef RUBY_VM
-      if (event != RUBY_EVENT_C_CALL && event != RUBY_EVENT_C_RETURN) {
-        // guess these are already set for C calls in 1.9, then?
+    /* if we don't have a valid method id, try to retrieve one */
+    if (mid == 0) {
         rb_frame_method_id_and_class(&mid, &klass);
-      }
-    #endif
+    }
 
     /* Get current measurement */
     measurement = profile->measurer->measure();
 
-    if (trace_file != NULL)
-    {
-#ifdef RUBY_VM
-        prof_trace(profile, event, mid, klass, measurement);
-#else
-        prof_trace(profile, event, node, mid, klass, measurement);
-#endif
-    }
-
     /* Special case - skip any methods from the mProf
        module or cProfile class since they clutter
        the results but aren't important to them results. */
     if (self == mProf || klass == cProfile)
 		return;
 
-    /* Get the current thread information. */
+    if (trace_file != NULL)
+    {
+        prof_trace(profile, event, mid, klass, measurement);
+    }
+
+    /* Get the current thread and fiber information. */
     thread = rb_thread_current();
     thread_id = rb_obj_id(thread);
-#if defined(HAVE_RB_FIBER_CURRENT)
     fiber = rb_fiber_current();
     fiber_id = rb_obj_id(fiber);
-#else
-    fiber = thread;
-    fiber_id = thread_id;
-#endif
 
     if (st_lookup(profile->exclude_threads_tbl, (st_data_t) thread_id, 0))
     {
@@ -284,11 +238,7 @@ prof_event_hook(rb_event_flag_t event, NODE *node, VALUE self, ID mid, VALUE kla
         prof_call_info_t *call_info = NULL;
         prof_method_t *method = NULL;
 
-        #ifdef RUBY_VM
         method = get_method(event, klass, mid, thread_data);
-        #else
-        method = get_method(event, node, klass, mid, thread_data);
-        #endif
 
         if (!frame)
         {
@@ -334,37 +284,15 @@ prof_event_hook(rb_event_flag_t event, NODE *node, VALUE self, ID mid, VALUE kla
 void
 prof_install_hook(VALUE self)
 {
-#ifdef RUBY_VM
     rb_add_event_hook(prof_event_hook,
           RUBY_EVENT_CALL | RUBY_EVENT_RETURN |
-          RUBY_EVENT_C_CALL | RUBY_EVENT_C_RETURN
-            | RUBY_EVENT_LINE, self); // RUBY_EVENT_SWITCH
-#else
-    rb_add_event_hook(prof_event_hook,
-          RUBY_EVENT_CALL | RUBY_EVENT_RETURN |
-          RUBY_EVENT_C_CALL | RUBY_EVENT_C_RETURN
-          | RUBY_EVENT_LINE);
-
-    pCurrentProfile = prof_get_profile(self);
-#endif	
-
-#if defined(TOGGLE_GC_STATS)
-    rb_gc_enable_stats();
-#endif
+          RUBY_EVENT_C_CALL | RUBY_EVENT_C_RETURN |
+          RUBY_EVENT_LINE, self);
 }
 
 void
 prof_remove_hook()
 {
-#if defined(TOGGLE_GC_STATS)
-    rb_gc_disable_stats();
-#endif
-
-#ifndef RUBY_VM
-    pCurrentProfile = NULL;
-#endif
-
-    /* Now unregister from event   */
     rb_remove_event_hook(prof_event_hook);
 }
 
@@ -508,19 +436,12 @@ prof_start(VALUE self)
     char* trace_file_name;
 
     prof_profile_t* profile = prof_get_profile(self);
-        
+
     if (profile->running == Qtrue)
     {
         rb_raise(rb_eRuntimeError, "RubyProf.start was already called");
     }
 
-#ifndef RUBY_VM
-	if (pCurrentProfile != NULL)
-    {
-        rb_raise(rb_eRuntimeError, "Only one profile can run at a time on Ruby 1.8.*");
-    }
-#endif
-
     profile->running = Qtrue;
     profile->paused = Qfalse;
     profile->last_thread_data = NULL;
@@ -674,8 +595,7 @@ prof_threads(VALUE self)
 void Init_ruby_prof()
 {
     mProf = rb_define_module("RubyProf");
-    rb_define_const(mProf, "VERSION", rb_str_new2(RUBY_PROF_VERSION));
-    
+
     rp_init_measure();
     rp_init_method_info();
     rp_init_call_info();
